@@ -64,7 +64,7 @@ class DocumentField:
         try:
             return self.document_cls is other.document_cls and self.name == other.name
         except AttributeError:
-            raise TypeError(f"Can't compare {other} to DocumentField.")
+            raise TypeError(f"Can't compare {other} to DocumentField.") from None
 
 
 class DocumentRelations:
@@ -200,7 +200,7 @@ class Document(metaclass=MetaDocument):
                 return DocumentArray(self._document_[item])
             return self._document_[item]
         except KeyError:
-            raise AttributeError(item)
+            raise AttributeError(item) from None
 
     def __setattr__(self, key, value):
         self._document_[key] = value
