@@ -1,4 +1,8 @@
-from collections import MutableMapping, ItemsView
+
+try:
+    from collections import MutableMapping
+except ImportError:
+    from collections.abc import MutableMapping
 
 
 class DocumentDict(MutableMapping):
